<template>
  <div class="fixed-asset">
    <div class="asset-left">
      <div class="statistics">
        <img src="@/assets/img/publicTitle/statistics-固定.png" alt="">
        <div class="statistics-content">
          <div class="title">总账面价值(万元)</div>
          <div class="num">818.67</div>
          <div class="line"></div>
          <div class="totality">总共盘点资产<span>21232 个</span></div>
        </div>
      </div>
      <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-固定资产.png')" title="各类型资产统计" />
      <div id="type-chart"></div>
    </div>
    <div class="asset-center">
      <div class="center-top">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-固定资产.png')" title="资产盘点" />
        <div id="check-chart"></div>
      </div>
      <div class="center-bottom">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-固定资产.png')" title="报废数量统计" />
        <div id="scrap-chart"></div>
      </div>
    </div>
    <div class="asset-right">
      <div class="right-top">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-固定资产.png')" title="出售数量分析" />
        <div id="sell-chart"></div>
      </div>
      <div class="right-bottom">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-固定资产.png')" title="退库数量分析" />
        <div id="return-chart"></div>
      </div>
    </div>
  </div>
</template>

<script>
import * as echarts from 'echarts'
import utils from '@/utils.js'
import PublicTitle from '@/components/PublicTitle/index'
export default {
  name: 'FixedAsset',
  components: {
    PublicTitle,
  },
  data() {
    return {}
  },
  created() {

  },
  mounted() {
    this.$nextTick(() => {
      this.initTypeChat()
      this.initSourceChat()
      this.initChat()
      this.initReturnChat()
      this.initCheckChat()
    })
  },
  methods: {
    //各类型资产统计
    initTypeChat() {
      let xData = ['办公用品', '办公设备', '办公家具', '电脑', '公务车辆', '服务器', '工作站', '机房']
      let bookData = [22, 44, 22, 11, 20, 44, 23, 56, 77]
      // this.statusData.forEach(e => {
      //   xData.push(this.getDictName('zczt', e.assetStatus))
      //   bookData.push(e.bookValue)
      //   structureData.push(e.structure_area_)
      // })
      let chartDom = echarts.init(
        document.getElementById('type-chart')
      )
      let option = {
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            // 坐标轴指示器，坐标轴触发有效
            type: 'shadow', // 默认为直线，可选为：'line' | 'shadow'
          },
        },
        legend: {
          align: 'left',
          padding: [15, 0, 0, 0],
        },
        grid: {
          left: '1%',
          right: '4%',
          bottom: '0',
          containLabel: true,
        },
        xAxis: [
          {
            type: 'value',

            axisTick: {
              show: false,
            },
            axisLine: {
              show: true,
              lineStyle: {
                color: '#A1A9B2', // 浅灰色
              },
            },
          },
        ],
        yAxis: [
          {
            type: 'category',
            data: xData,

            name: '单位：个',
            axisLabel: {
              formatter: '{value}',

            },
            splitLine: {
              show: false,
            },
            axisLine: {
              show: true,
              lineStyle: {
                color: '#A1A9B2', // 浅灰色
              },
            },
          }
        ],
        series: [
          {
            type: 'bar',
            data: bookData,
            barWidth: '15',
            stack: 'user',
            label: {
                show: true, // 显示标签
                position: 'right',
                fontSize: 16,
                color: '#000',
                offset: [10, 2],
              },
            itemStyle: {
              color: {
                type: 'linear',
                x: 1,
                y: 0,
                x2: 0,
                y2: 0,
                colorStops: [
                  {
                    offset: 0,
                    color: '#198CFF', // 渐变起始颜色（绿色）
                  },
                  {
                    offset: 1,
                    color: 'rgba(25, 140, 255,0.2)', // 渐变结束颜色（深绿色）
                  },
                ],
              },
            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
    },
    //资产盘点
    initCheckChat() {
      let echartsData = [
        {
          name: '盘亏资产',
          value: 5,
          itemStyle: {
            color: '#55EDB0',
          },
        }, {
          name: '盘盈资产',
          value: 15,
          itemStyle: {
            color: '#00D4FF ',
          },
        }
      ]
      // this.typeData.forEach((e, index) => {
      //   echartsData.push({
      //     name: this.getDictName('zclx', e.assetType),
      //     value: e.count,
      //     itemStyle: {
      //       color: this.colorList[index],
      //     },
      //   })
      // })
      let chartDom = echarts.init(document.getElementById('check-chart'))
      let option = {
        tooltip: {
          trigger: 'item',
        },
        legend: {
          orient: 'vertical',
          top: 'middle',
          right: 90,
          selectedMode: false
        },
        series: [
          {
            name: '面积',
            type: 'pie',
            radius: ['55%', '67%'],
            center: ['35%', '48.4%'],
            avoidLabelOverlap: false,
            itemStyle: {
              borderColor: '#fff',
              borderWidth: 2,
            },
            label: {
              show: false,
              position: 'center',
            },

            emphasis: {
              label: {
                show: true,
                fontSize: 30,
                formatter: function (params) {
                  return [
                    '{num|' +
                    params.value +
                    '}' +
                    '{unit|个}',
                    '{label|' + params.name + '}',
                  ].join('\n')
                },
                rich: {
                  num: {
                    fontSize: 30,
                    color: '#000',
                    lineHeight: 30,
                    fontWeight: 700,
                  },
                  unit: {
                    fontSize: 14,
                    color: '#111',
                    lineHeight: 30,
                    padding: [0, 5],
                  },
                  label: {
                    fontSize: 20,
                    lineHeight: 30,
                    color: '#444',
                  },
                },
              },
            },
            labelLine: {
              show: false,
            },
            data: echartsData,
          },
          // 外圈背景
          {
            type: 'pie',
            radius: ['50%', '50%'],
            center: ['35%', '48.4%'],
            hoverAnimation: false,
            clockWise: false,
            cursor: 'default',
            itemStyle: {
              normal: {
                borderWidth: 2,
                borderColor: '#eaeaea',
              },
            },
            tooltip: {
              show: false,
            },
            label: {
              show: false,
            },
            data: [100],
          },
          {
            type: 'gauge',
            radius: '98%',
            center: ['35%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 200, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 15,
              lineStyle: {
                color: '#eaeaea',
                width: 1,
              },
            },
            axisLabel: {
              show: false,
            },
          },
          {
            type: 'gauge',
            radius: '83.5%',
            center: ['35%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 140, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 1,
              lineStyle: {
                color: '#eaeaea',
                width: 2,
              },
            },
            axisLabel: {
              show: false,
            },
          },


        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
      handleChartLoop(option, chartDom);
      // 饼图自动轮播
      function handleChartLoop(option, myChart) {
        if (!myChart) {
          return
        }
        let currentIndex = 0 // 当前高亮图形在饼图数据中的下标
        highlightPie()
        // 取消所有高亮并高亮当前图形
        function highlightPie() {
          // 遍历饼图数据，取消所有图形的高亮效果
          for (var idx in option.series[0].data) {
            myChart.dispatchAction({
              type: 'downplay',
              seriesIndex: 0,
              dataIndex: idx
            })
          }
          // 高亮当前图形
          myChart.dispatchAction({
            type: 'highlight',
            seriesIndex: 0,
            dataIndex: currentIndex
          })
        }
        // // 用户鼠标悬浮到某一图形时，停止自动切换并高亮鼠标悬浮的图形
        myChart.on('mouseover', (params) => {
          if (params.componentType == 'graphic') {
            return
          }
          currentIndex = params.dataIndex
          highlightPie()
        })
      }
    },
    //报废数量统计
    initSourceChat() {
      let xData = ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月']
      let bookData = [22, 44, 22, 11, 20, 44, 23, 56, 77, 44, 42, 31]
      // this.statusData.forEach(e => {
      //   xData.push(this.getDictName('zczt', e.assetStatus))
      //   bookData.push(e.bookValue)
      //   structureData.push(e.structure_area_)
      // })
      let chartDom = echarts.init(
        document.getElementById('scrap-chart')
      )
      let option = {
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            // 坐标轴指示器，坐标轴触发有效
            type: 'shadow', // 默认为直线，可选为：'line' | 'shadow'
          },
        },
        legend: {
          align: 'left',
          padding: [15, 0, 0, 0],
        },
        grid: {
          left: '3%',
          right: '4%',
          bottom: '0',
          containLabel: true,
        },
        xAxis: [
          {
            type: 'category',
            data: xData,
            axisTick: {
              show: false,
            },
            axisLine: {
              show: true,
              lineStyle: {
                color: '#A1A9B2', // 浅灰色
              },
            },
          },
        ],
        yAxis: [
          {
            type: 'value',
            name: '单位：个',
            axisLabel: {
              formatter: '{value}',

            },
            splitLine: {
              show: false,
            },
            axisLine: {
              show: true,
              lineStyle: {
                color: '#A1A9B2', // 浅灰色
              },
            },
          }
        ],
        series: [
          {
            type: 'bar',
            data: bookData,
            barWidth: '15',
            stack: 'user',
            itemStyle: {
              color: '#FFB56B', // 渐变起始颜色（绿色）
            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
    },
    //出售数量分析
    initChat() {
      let xData = ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月']
      let bookData = [22, 44, 22, 11, 20, 44, 23, 56, 77, 44, 42, 31]

      let chartDom = echarts.init(
        document.getElementById('sell-chart')
      )
      let option = {
        tooltip: {
          trigger: 'axis', // 设置触发类型为坐标轴轴线触发
        },
        grid: {
          top: '10%',
          bottom: '5%',
          right: '3%',
          left: '5%'
        },
        xAxis: {
          type: 'category',
          data: xData,
          boundaryGap: false,
          axisTick: {
            show: false,
          },
          axisLine: {
            show: true,
            lineStyle: {
              color: '#A1A9B2', // 浅灰色
            },
          },
        },
        yAxis: {
          type: 'value',
          name: '单位：个',
          axisLine: {
            show: true,
            lineStyle: {
              color: '#A1A9B2', // 浅灰色
            },
          },
          splitLine: {
            show: false,
          },
        },
        series: [
          {
            type: 'line',
            data: bookData,
            type: 'line',
            smooth: true,
            // symbol: 'none', // 取消小圆点的显示
            showSymbol: false, // 取消小圆点的显示
            lineStyle: {
              color: '#198CFF', // 设置线条的颜色为红色
            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
    },
    //退库数量分析
    initReturnChat() {
      let xData = ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月']
      let bookData = [22, 44, 22, 11, 20, 44, 23, 56, 77, 44, 42, 31]

      let chartDom = echarts.init(
        document.getElementById('return-chart')
      )
      let option = {
        tooltip: {
          trigger: 'axis', // 设置触发类型为坐标轴轴线触发
        },
        grid: {
          top: '10%',
          bottom: '5%',
          right: '3%',
          left: '5%'
        },
        xAxis: {
          type: 'category',
          data: xData,
          boundaryGap: false,
          axisTick: {
            show: false,
          },
          axisLine: {
            show: true,
            lineStyle: {
              color: '#A1A9B2', // 浅灰色
            },
          },
        },
        yAxis: {
          type: 'value',
          name: '单位：个',
          axisLine: {
            show: true,
            lineStyle: {
              color: '#A1A9B2', // 浅灰色
            },
          },
          splitLine: {
            show: false,
          },
        },
        series: [
          {
            type: 'line',
            data: bookData,
            type: 'line',
            smooth: true,
            // symbol: 'none', // 取消小圆点的显示
            showSymbol: false, // 取消小圆点的显示
            lineStyle: {
              color: '#198CFF', // 设置线条的颜色为红色
            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
    },
  }
}
</script>

<style lang="scss" scoped>
.fixed-asset {
  // box-sizing: border-box;
  // padding: 15px 0;
  width: 100%;
  height: 100%;
  padding: 16px 24px;
  box-sizing: border-box;
  display: flex;
  justify-content: space-between;
  align-items: center;

  .asset-left {
    width: 30%;
    height: 100%;
    padding: 16px;
    box-sizing: border-box;
    background: #FFFFFF;
    box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
    border-radius: 16px 16px 16px 16px;
    opacity: 1;

    .statistics {
      height: 152px;
      background: #198CFF;
      border-radius: 8px 8px 8px 8px;
      padding: 0 16px;
      box-sizing: border-box;
      margin-bottom: 40px;
      display: flex;
      align-items: center;

      img {
        width: 164px;
        height: 152px;
      }

      .statistics-content {
        height: 100%;
        padding: 24px 0;
        box-sizing: border-box;
        display: flex;
        flex-direction: column;
        justify-content: space-evenly;

        .title {
          font-size: 16px;
          font-family: Microsoft YaHei, Microsoft YaHei;
          font-weight: 400;
          color: #FFFFFF;
          line-height: 21px;
        }

        .num {
          font-size: 26px;
          font-family: Microsoft YaHei, Microsoft YaHei;
          font-weight: 700;
          color: #FFFFFF;
          line-height: 26px;
        }

        .line {
          width: 233px;
          height: 0px;
          opacity: 1;
          border: 1px solid #E6F1FF;
        }

        .totality {
          font-size: 14px;
          font-family: Microsoft YaHei, Microsoft YaHei;
          font-weight: 400;
          color: #FFFFFF;
          line-height: 18px;

          span {
            font-size: 16px;
            font-family: Microsoft YaHei, Microsoft YaHei;
            font-weight: 700;
            color: #FFFFFF;
            line-height: 21px;
          }
        }
      }
    }

    #type-chart {
      width: 100%;
      height: calc(100% - 222px);
    }
  }

  .asset-center {
    width: calc(35% - 16px);
    height: 100%;
    display: flex;
    flex-direction: column;
    justify-content: space-between;
    align-items: center;

    .center-top {
      width: 100%;
      height: calc(50% - 8px);
      padding: 16px;
      box-sizing: border-box;
      background: #FFFFFF;
      box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
      border-radius: 16px 16px 16px 16px;
      opacity: 1;

      #check-chart {
        width: 100%;
        height: calc(100% - 30px);
      }
    }

    .center-bottom {
      width: 100%;
      height: calc(50% - 8px);
      padding: 16px;
      box-sizing: border-box;
      background: #FFFFFF;
      box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
      border-radius: 16px 16px 16px 16px;
      opacity: 1;

      #scrap-chart {
        width: 100%;
        height: calc(100% - 30px);
      }
    }
  }

  .asset-right {
    width: calc(35% - 16px);
    height: 100%;
    display: flex;
    flex-direction: column;
    justify-content: space-between;
    align-items: center;

    .right-top {
      width: 100%;
      height: calc(50% - 8px);
      padding: 16px;
      box-sizing: border-box;
      background: #FFFFFF;
      box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
      border-radius: 16px 16px 16px 16px;
      opacity: 1;

      #sell-chart {
        width: 100%;
        height: calc(100% - 30px);
      }
    }

    .right-bottom {
      width: 100%;
      height: calc(50% - 8px);
      padding: 16px;
      box-sizing: border-box;
      background: #FFFFFF;
      box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
      border-radius: 16px 16px 16px 16px;
      opacity: 1;

      #return-chart {
        width: 100%;
        height: calc(100% - 30px);
      }
    }
  }
}
</style>
